@@ -71,8 +71,8 @@ class MMActuator(QObject):
 
         self.gui = MMActuatorGUI(self, self.calibration) if gui else None
 
-        self.calibrated_wait_time = None
-        self.auto_adjust = True
+        self.calibrated_wait_time = settings.get_settings(self)["calibration"]
+        self.auto_adjust = False
 
         self.event_bus.new_interpretation.connect(self.call_action)
         self.event_bus.acquisition_ended_event.connect(self._stop_acq)
@@ -102,6 +102,10 @@ class MMActuator(QObject):
             )
         else:
             self.acquisition = self.acquisition_mode(self.event_bus)
+
+        if not self.acquisition.setup_success:
+            return False
+
         self.acquisition.acquisition_ended.connect(self.reset_thread)
         self.stop_acq_signal.connect(self.acquisition.stop_acq)
         self.new_interval.connect(self.acquisition.change_interval)
@@ -163,12 +167,12 @@ class MMAcquisition(QThread):
     def __init__(self, event_bus: EventBus):
         """Get the settings from MM and settings.json and store."""
         super().__init__()
+        self.setup_success = False
         self.studio = event_bus.studio
         self.event_bus = event_bus
         self.settings = self.studio.acquisitions().get_acquisition_settings()
         # TODO: Set interval to fast interval so it can be used when running freely
         self.channels = self.get_channel_information()
-        # This has to be higher for 1 channel, otherwise it will be a burst acq that can't be paused
 
         default_settings = settings.get_settings(__class__)
         self.channel_switch_time = default_settings["channel_switch_time_ms"]
@@ -178,7 +182,16 @@ class MMAcquisition(QThread):
         log.info(f"Settings: {self.slices} slices & {self.num_channels} channels")
 
         num_frames = self.num_channels * self.slices
-        interval = 0 if num_frames > 1 else self.channels[0] + 1
+
+        try:
+            # This has to be higher for 1 channel, otherwise it will be a burst acq that can't be paused
+            interval = 0 if num_frames > 1 else self.channels[0] + 1
+        except IndexError:
+            log.warning(
+                "No channels selected in MDA window, please select at least one channel."
+            )
+            return None
+
         log.info(f"Interval {interval}")
         self.settings = self.settings.copy_builder().interval_ms(interval).build()
 
@@ -186,6 +199,7 @@ class MMAcquisition(QThread):
         self.acq_eng = self.studio.get_acquisition_engine()
 
         self.stop = False
+        self.setup_success = True
 
     def start(self):
         """Start the QThread first, then yourself."""
@@ -227,7 +241,7 @@ class TimerMMAcquisition(MMAcquisition):
         studio,
         start_interval: float = 5.0,
         calibrated_wait_time: float = None,
-        auto_adjust: bool = True,
+        auto_adjust: bool = False,
     ):
         """Initialise the QTimer and connect signals."""
         super().__init__(studio)
@@ -287,6 +301,9 @@ class TimerMMAcquisition(MMAcquisition):
     def acquire(self):
         """Open acquisition for a short time in slow mode."""
         log.debug(f"acquire {self.calibrated_wait_time}")
+        self.calibrated_wait_time = (
+            None if self.calibrated_wait_time == 0 else self.calibrated_wait_time
+        )
         self.acquire_num += 1
         if self.calibrated_wait_time is None:
             wait_time = sum(self.channels) / 1000 + self.channel_switch_time / 1000 * (
@@ -395,6 +412,7 @@ class TimerMMAcquisition(MMAcquisition):
             .build()
         )
 
+        settings.set_settings("calibration", self.calibrated_wait_time, self)
         # Get the dialog to disbale custom intervals, as this is sometimes buggy in MM
         # dialog = self.event_bus.event_thread.bridge.construct_java_object(
         #     "org.micromanager.internal.dialogs.CustomTimesDialog",
@@ -432,16 +450,21 @@ class TimerMMAcquisition(MMAcquisition):
             self.acquisitions.set_pause(False)
             time.sleep((wait_time + step_now) / 1000)
             self.acquisitions.set_pause(True)
-            time.sleep(0.5)
+            time.sleep(0.7)
             missing_images = num_frames - datastore.get_num_images()
             if missing_images == 0 and first_hit is None:
                 first_hit = wait_time + step_now
             step_now += step
             self.acquisitions.set_pause(False)
-            time.sleep(wait_time * 2)
+            time.sleep(wait_time / 300)
             self.acquisitions.halt_acquisition()
-            print(int(wait_time + step_now), missing_images)
-        return (first_hit + wait_time + step_now) / 2
+            print(
+                f"acq_time: {int(wait_time + step_now)} image_offset: {missing_images}"
+            )
+
+        mean = (first_hit + wait_time + step_now) / 2
+        diff = wait_time + step_now - first_hit
+        return mean - diff * 0.33
 
     def _initial_calibration(self, old_settings):
         num_timepoints = 5
@@ -542,13 +565,15 @@ class MMActuatorGUI(QWidgetRestore):
         if calibrate:
             self.calib_button = QtWidgets.QPushButton("Calibrate")
             self.calib_button.clicked.connect(self._calib)
-            self.calib_edit = QtWidgets.QLineEdit("0")
+            self.calib_edit = QtWidgets.QLineEdit()
             self.calib_edit.textChanged.connect(
                 self.actuator.set_calibrated_time_from_gui
             )
+            calib = settings.get_settings(self)["calibration"]
+            self.calib_edit.setText(str(int(calib)))
             self.calib_check = QtWidgets.QCheckBox()
             self.calib_check.stateChanged.connect(self.actuator.set_auto_adjust)
-            self.calib_check.setChecked(True)
+            self.calib_check.setChecked(False)
 
         grid = QtWidgets.QFormLayout(self)
         grid.addRow(self.start_button)
